@@ -16,6 +16,7 @@ from agentbox.api.client.api.sandboxes import (
     post_sandboxes,
     get_sandboxes_sandbox_id_adb,
     get_sandboxes_sandbox_id_ssh,
+    get_sandboxes_sandbox_id_instance_no,
 )
 from agentbox.connection_config import ConnectionConfig, ProxyTypes
 from agentbox.api import handle_api_exception
@@ -162,6 +163,55 @@ class SandboxApi(SandboxApiBase):
                 envd_version=res.parsed.envd_version,
                 _envd_access_token=res.parsed.envd_access_token,
             )
+        
+    @classmethod
+    async def get_instance_no(
+        cls,
+        sandbox_id: str,
+        api_key: Optional[str] = None,
+        domain: Optional[str] = None,
+        debug: Optional[bool] = None,
+        request_timeout: Optional[float] = None,
+        headers: Optional[Dict[str, str]] = None,
+        proxy: Optional[ProxyTypes] = None,
+    ) -> SandboxInfo:
+        """
+        Get the sandbox instance number.
+        :param sandbox_id: Sandbox ID
+        :param api_key: API key to use for authentication, defaults to `E2B_API_KEY` environment variable
+        :param domain: Domain to use for the request, defaults to `E2B_DOMAIN` environment variable
+        :param debug: Debug mode, defaults to `E2B_DEBUG` environment variable
+        :param request_timeout: Timeout for the request in **seconds**
+        :param headers: Additional headers to send with the request
+        :param proxy: Proxy to use for the request
+
+        :return: Sandbox instance number
+        """
+        config = ConnectionConfig(
+            api_key=api_key,
+            domain=domain,
+            debug=debug,
+            request_timeout=request_timeout,
+            headers=headers,
+            proxy=proxy,
+        )
+
+        async with AsyncApiClient(
+            config,
+            limits=SandboxApiBase._limits,
+        ) as api_client:
+            res = await get_sandboxes_sandbox_id_instance_no.asyncio_detailed(
+                sandbox_id,
+                client=api_client,
+            )
+
+            if res.status_code >= 300:
+                raise handle_api_exception(res)
+
+            if res.parsed is None:
+                raise Exception("Body of the request is None")
+
+            return res.parsed
 
     @classmethod
     async def _get_adb(
