@@ -12,7 +12,7 @@ from agentbox.exceptions import SandboxException, format_request_timeout_error
 from agentbox.sandbox.main import SandboxSetup
 from agentbox.sandbox.utils import class_method_variant
 from agentbox.sandbox_sync.adb_shell.adb_shell import ADBShell
-from agentbox.sandbox_sync.filesystem.filesystem import Filesystem
+from agentbox.sandbox_sync.filesystem.filesystem import AgentBoxFilesystem as Filesystem
 from agentbox.sandbox_sync.commands.command import Commands
 from agentbox.sandbox_sync.commands.pty import Pty
 from agentbox.sandbox_sync.sandbox_api import SandboxApi, SandboxInfo
@@ -556,3 +556,24 @@ class Sandbox(SandboxSetup, SandboxApi):
             sandbox_id=self.sandbox_id,
             **config_dict,
         )
+    
+    def get_instance_no(  # type: ignore
+        self,
+        request_timeout: Optional[float] = None,
+    ) -> str:
+        """
+        Get sandbox instance number.
+        :param request_timeout: Timeout for the request in **seconds**
+        :return: Sandbox instance number
+        """
+        config_dict = self.connection_config.__dict__
+        config_dict.pop("access_token", None)
+        config_dict.pop("api_url", None)
+
+        if request_timeout:
+            config_dict["request_timeout"] = request_timeout
+
+        return SandboxApi.get_instance_no(
+            sandbox_id=self.sandbox_id,
+            **config_dict,
+        )
